@@ -5,7 +5,7 @@ use warnings;
 use Carp;
 use Data::Dumper;
 
-our $VERSION = '1.27';
+our $VERSION = '1.28';
 
 sub new {
 
@@ -179,7 +179,8 @@ sub objects {
             #FIXME: this eval catch catches bad dispatch and "not a hashref"
 
             if ($@){
-                print "dispatch table in engine has a mistyped function value\n\n";
+                print "dispatch table in engine has a mistyped function " .
+                      "value\n\n";
                 confess $@;
             }
 
@@ -196,25 +197,30 @@ __END__
 
 =head1 NAME
 
-Devel::Examine::Subs::Prefilter - Provides core Pre-Filter callbacks for Devel::Examine::Subs
+Devel::Examine::Subs::Prefilter - Provides core Pre-Filter callbacks for
+Devel::Examine::Subs
 
 =head1 DESCRIPTION
 
-This module generates and supplies the core prefilter module callbacks. Prefilters run after the core Processor, and before any Engine is run.
+This module generates and supplies the core prefilter module callbacks.
+Prefilters run after the core Processor, and before any Engine is run.
 
 =head1 SYNOPSIS
 
-Pre-filters can be daisy chained as text strings that represent a built-in prefilter, or as callbacks, or both.
+Pre-filters can be daisy chained as text strings that represent a built-in
+prefilter, or as callbacks, or both.
 
 See C<Devel::Examine::Subs::_pre_filter()> for implementation details.
 
 =head1 METHODS
 
-All methods other than C<exists()> takes an href of configuration data as it's first parameter.
+All methods other than C<exists()> takes an href of configuration data as its
+first parameter.
 
 =head2 C<exists('prefilter')>
 
-Verifies whether the prefilter name specified as the string parameter exists and is valid.
+Verifies whether the prefilter name specified as the string parameter exists
+and is valid.
 
 =head2 C<subs()>
 
@@ -223,7 +229,8 @@ Returns an aref of hash refs, each containing info per sub.
 
 =head2 C<file_lines_contain()>
 
-Returns an aref similar to C<subs()>, but includes an array within each sub href that contains lines that match a search term.
+Returns an aref similar to C<subs()>, but includes an array within each sub
+href that contains lines that match a search term.
 
 =head2 C<end_of_last_sub()>
 
@@ -245,8 +252,9 @@ You can find documentation for this module with the perldoc command.
 
 Copyright 2015 Steve Bertrand.
 
-This program is free software; you can redistribute it and/or modify it under the terms of either: the GNU General Public License as 
-published by the Free Software Foundation; or the Artistic License.
+This program is free software; you can redistribute it and/or modify it under
+the terms of either: the GNU General Public License as published by the Free
+Software Foundation; or the Artistic License.
 
 See http://dev.perl.org/licenses/ for more information.
 
